<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ja',
    'no' => 'Nej',
    'update' => 'Uppdatera',
    'save' => 'Spara',
    'add' => 'Lägg till',
    'cancel' => 'Avbryt',
    'confirm' => 'Bekräfta',
    'delete_confirm' => 'Är du säker?',
    'delete' => 'Radera',
    'edit' => 'Redigera',
    'upload' => 'Ladda upp',
    'download' => 'Hämta',
    'save_close' => 'Spara och stäng',
    'close' => 'Stäng',
    'copy' => 'Kopiera',
    'create' => 'Skapa',
    'remove' => 'Radera',
    'revoke' => 'Återkalla',
    'done' => 'Klar',
    'back' => 'Tillbaka',
    'verify' => 'Verifiera',
    'new' => 'ny',
    'unknown' => 'Jag vet inte',
    'load_more' => 'Ladda mer',
    'loading' => 'Laddar…',
    'with' => 'med',
    'today' => 'idag',
    'yesterday' => 'igår',
    'another_day' => 'en annan dag',
    'date' => 'Datum',
    'type' => 'Typ',
    'zoom' => 'Zoom',
    'upgrade' => 'Uppgradera för att låsa upp',
    'percent_uploaded' => '{percent}% uppladdat',
    'retry' => 'Försök igen',
    'filter' => 'Filtrera listan',
    'go_back' => 'Gå tillbaka',
    'file_selected' => 'En fil vald…|{count} filer valda…',

    'application_title' => 'Monica – Personlig Relationsansvarig',
    'application_description' => 'Monica är ett verktyg för att hantera dina interaktioner med dina nära och kära, vänner och familj.',
    'application_og_title' => 'Skapa bättre relationer med dina nära och kära. Gratis online CRM för vänner och familj.',

    'markdown_description' => 'Vill du formatera din text fint? Vi stöder Markdown för att lägga till fetstil, kursiva, listor och mycket mer.',
    'markdown_link' => 'Läs dokumentation',

    'header_settings_link' => 'Inställningar',
    'header_logout_link' => 'Logga ut',
    'header_changelog_link' => 'Produkt ändringar',

    'main_nav_cta' => 'Lägg till personer',
    'main_nav_dashboard' => 'Instrumentpanel',
    'main_nav_family' => 'Kontakter',
    'main_nav_journal' => 'Dagbok',
    'main_nav_activities' => 'Aktiviteter',
    'main_nav_tasks' => 'Uppgifter',

    'footer_remarks' => 'Kommentarer?',
    'footer_send_email' => 'Skicka ett mail till oss',
    'footer_privacy' => 'Integritetspolicy',
    'footer_release' => 'Information om utgivningen',
    'footer_newsletter' => 'Nyhetsbrev',
    'footer_source_code' => 'Bidra',
    'footer_version' => 'Version: :version',
    'footer_new_version' => 'En ny version av Monica är tillgänglig',

    'footer_modal_version_whats_new' => 'Vad är nytt',
    'footer_modal_version_release_away' => 'Du är 1 version bakom den senaste versionen. Du bör uppdatera din instans.|Du är :number releaser bakom den senaste versionen. Du bör uppdatera din instans.',

    'breadcrumb_dashboard' => 'Instrumentpanel',
    'breadcrumb_list_contacts' => 'Lista över personer',
    'breadcrumb_archived_contacts' => 'Arkiverade kontakter',
    'breadcrumb_journal' => 'Dagbok',
    'breadcrumb_settings' => 'Inställningar',
    'breadcrumb_settings_export' => 'Exportera',
    'breadcrumb_settings_users' => 'Användare',
    'breadcrumb_settings_users_add' => 'Lägg till en användare',
    'breadcrumb_settings_subscriptions' => 'Prenumeration',
    'breadcrumb_settings_import' => 'Importera',
    'breadcrumb_settings_import_report' => 'Importera rapport',
    'breadcrumb_settings_import_upload' => 'Ladda upp',
    'breadcrumb_settings_tags' => 'Taggar',
    'breadcrumb_add_significant_other' => 'Lägg till partner/respektive',
    'breadcrumb_edit_significant_other' => 'Redigera partner/respektive',
    'breadcrumb_add_note' => 'Lägg till en anteckning',
    'breadcrumb_edit_note' => 'Redigera en anteckning',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV resurser',
    'breadcrumb_edit_introductions' => 'Hur träffades ni',
    'breadcrumb_settings_personalization' => 'Anpassa',
    'breadcrumb_settings_security' => 'Säkerhet',
    'breadcrumb_settings_security_2fa' => 'Tvåfaktorsautentisering',
    'breadcrumb_profile' => 'Profil för :name',

    'gender_male' => 'Man',
    'gender_female' => 'Kvinna',
    'gender_none' => 'Vill inte säga',
    'gender_no_gender' => 'Inget kön',

    'error_title' => 'Hoppsan! Något gick fel.',
    'error_unauthorized' => 'Du har inte rätt att redigera denna resurs.',
    'error_user_account' => 'Den här användaren tillhör inte det angivna kontot.',
    'error_save' => 'Ett fel uppstod när vi försökte spara data.',
    'error_try_again' => 'Något gick fel. Försök igen.',
    'error_id' => 'Fel ID: ID',
    'error_unavailable' => 'Tjänsten är inte tillgänglig',
    'error_maintenance' => 'Underhåll pågår, vi återkommer strax.',
    'error_help' => 'Vi kommer snart tillbaka.',
    'error_twitter' => 'Följ <a href="https://twitter.com/:twitter">vårt Twitter-konto</a> för att bli uppdaterad när sidan är uppe igen.',
    'error_no_term' => 'Det finns ingen policy för denna instans ännu.',

    'default_save_success' => 'Datan har sparats.',

    'compliance_title' => 'Ledsen för avbrottet.',
    'compliance_desc' => 'Vi har ändrat våra <a href=":urlterm" hreflang=":hreflang">användarvillkor</a> och <a href=":url" hreflang=":hreflang">sekretesspolicy</a>. Enligt lag måste vi be dig granska dem och acceptera dem så att du kan fortsätta använda ditt konto.',
    'compliance_desc_end' => 'Vi gör inget otäckt med dina uppgifter eller ditt konto och vi kommer aldrig att göra det.',
    'compliance_terms' => 'Acceptera nya villkor och sekretesspolicy',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Kärleksrelationer',
    'relationship_type_group_family' => 'Familjerelationer',
    'relationship_type_group_friend' => 'Vänrelationer',
    'relationship_type_group_work' => 'Arbetsrelationer',
    'relationship_type_group_other' => 'Annan typ av relationer',

    'relationship_type_partner' => 'partner',
    'relationship_type_partner_female' => 'partner',
    'relationship_type_partner_male' => 'partner',
    'relationship_type_partner_with_name' => '.name\'s partner',
    'relationship_type_partner_female_with_name' => ':name\'s partner',
    'relationship_type_partner_male_with_name' => ':name’s partner',

    'relationship_type_spouse' => 'make',
    'relationship_type_spouse_female' => 'fru',
    'relationship_type_spouse_male' => 'make',
    'relationship_type_spouse_with_name' => ':name\'s make',
    'relationship_type_spouse_female_with_name' => ':name’s fru',
    'relationship_type_spouse_male_with_name' => ':name’s make',

    'relationship_type_date' => 'dejt',
    'relationship_type_date_female' => 'dejt',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => ':name\'s dejt',
    'relationship_type_date_female_with_name' => ':name\'s dejt',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'älskare',
    'relationship_type_lover_female' => 'älskare',
    'relationship_type_lover_male' => 'älskare',
    'relationship_type_lover_with_name' => ':name\'s älskare',
    'relationship_type_lover_female_with_name' => ':name\'s älskarinna',
    'relationship_type_lover_male_with_name' => ':name’s älskare',

    'relationship_type_inlovewith' => 'kär i',
    'relationship_type_inlovewith_female' => 'kär i',
    'relationship_type_inlovewith_male' => 'kär i',
    'relationship_type_inlovewith_with_name' => 'någon :name är kär i',
    'relationship_type_inlovewith_female_with_name' => 'någon :name är kär i',
    'relationship_type_inlovewith_male_with_name' => 'någon :name är kär i',

    'relationship_type_lovedby' => 'älskad av',
    'relationship_type_lovedby_female' => 'älskad av',
    'relationship_type_lovedby_male' => 'älskad av',
    'relationship_type_lovedby_with_name' => ':name\'s hemliga älskare',
    'relationship_type_lovedby_female_with_name' => ':name\'s hemliga älskarinna',
    'relationship_type_lovedby_male_with_name' => ':name\'s hemliga älskare',

    'relationship_type_ex' => 'föredetta',
    'relationship_type_ex_female' => 'ex-flickvän',
    'relationship_type_ex_male' => 'föredetta pojkvän',
    'relationship_type_ex_with_name' => ':name’s föredetta partner',
    'relationship_type_ex_female_with_name' => ':name\'s ex-flickvän',
    'relationship_type_ex_male_with_name' => ':name’s föredetta pojkvän',

    'relationship_type_parent' => 'förälder',
    'relationship_type_parent_female' => 'mor',
    'relationship_type_parent_male' => 'fader',
    'relationship_type_parent_with_name' => ':name’s förälder',
    'relationship_type_parent_female_with_name' => ':name\'s mamma',
    'relationship_type_parent_male_with_name' => ':name’s fader',

    'relationship_type_child' => 'barn',
    'relationship_type_child_female' => 'dotter',
    'relationship_type_child_male' => 'son',
    'relationship_type_child_with_name' => ':name\'s barn',
    'relationship_type_child_female_with_name' => ':name\'s dotter',
    'relationship_type_child_male_with_name' => ':name\'s son',

    'relationship_type_stepparent' => 'styvförälder',
    'relationship_type_stepparent_female' => 'styvmor',
    'relationship_type_stepparent_male' => 'styvfar',
    'relationship_type_stepparent_with_name' => ':name’s styvförälder',
    'relationship_type_stepparent_female_with_name' => ':name\'s styvmor',
    'relationship_type_stepparent_male_with_name' => ':name’s styvfar',

    'relationship_type_stepchild' => 'styvbarn',
    'relationship_type_stepchild_female' => 'styvdotter',
    'relationship_type_stepchild_male' => 'styvson',
    'relationship_type_stepchild_with_name' => ':name’s styvbarn',
    'relationship_type_stepchild_female_with_name' => ':name\'s styvdotter',
    'relationship_type_stepchild_male_with_name' => ':name’s styvson',

    'relationship_type_sibling' => 'syskon',
    'relationship_type_sibling_female' => 'syster',
    'relationship_type_sibling_male' => 'broder',
    'relationship_type_sibling_with_name' => ':name’s syskon',
    'relationship_type_sibling_female_with_name' => ':name\'s syster',
    'relationship_type_sibling_male_with_name' => ':name’s broder',

    'relationship_type_grandparent' => 'mor- eller farförälder',
    'relationship_type_grandparent_female' => 'farmor/mormor',
    'relationship_type_grandparent_male' => 'farfar/morfar',
    'relationship_type_grandparent_with_name' => ':name’s far- eller morförälder',
    'relationship_type_grandparent_female_with_name' => ':name’s far- eller mormoder',
    'relationship_type_grandparent_male_with_name' => ':name’s far- eller morfar',

    'relationship_type_grandchild' => 'barnbarn',
    'relationship_type_grandchild_female' => 'son-/dotterdotter',
    'relationship_type_grandchild_male' => 'son-/dotterson',
    'relationship_type_grandchild_with_name' => ':name’s barnbarn',
    'relationship_type_grandchild_female_with_name' => ':name’s son-/dotterdotter',
    'relationship_type_grandchild_male_with_name' => ':name’s son-/dotterson',

    'relationship_type_uncle' => 'farbror',
    'relationship_type_uncle_female' => 'moster',
    'relationship_type_uncle_male' => 'far-/morbror',
    'relationship_type_uncle_with_name' => ':name\'s farbror',
    'relationship_type_uncle_female_with_name' => ':name\'s moster',
    'relationship_type_uncle_male_with_name' => ':name’s far-/morbror',

    'relationship_type_nephew' => 'brorson',
    'relationship_type_nephew_female' => 'systerdotter',
    'relationship_type_nephew_male' => 'bror-/systerbarn',
    'relationship_type_nephew_with_name' => ':name\'s brorson',
    'relationship_type_nephew_female_with_name' => ':name\'s systerdotter',
    'relationship_type_nephew_male_with_name' => ':name’s bror-/systerbarn',

    'relationship_type_cousin' => 'kusin',
    'relationship_type_cousin_female' => 'kusin',
    'relationship_type_cousin_male' => 'kusin',
    'relationship_type_cousin_with_name' => ':name\'s kusin',
    'relationship_type_cousin_female_with_name' => ':name\'s kusin',
    'relationship_type_cousin_male_with_name' => ':name\'s kusin',

    'relationship_type_godfather' => 'gudförälder',
    'relationship_type_godfather_female' => 'gudmor',
    'relationship_type_godfather_male' => 'gudfar',
    'relationship_type_godfather_with_name' => ':name’s gudförälder',
    'relationship_type_godfather_female_with_name' => ':name\'s gudmamma',
    'relationship_type_godfather_male_with_name' => ':name’s gudfar',

    'relationship_type_godson' => 'gudson/-dotter',
    'relationship_type_godson_female' => 'guddotter',
    'relationship_type_godson_male' => 'gudson',
    'relationship_type_godson_with_name' => ':name’s gudson/-dotter',
    'relationship_type_godson_female_with_name' => ':name\'s guddotter',
    'relationship_type_godson_male_with_name' => ':name’s gudson',

    'relationship_type_friend' => 'vän',
    'relationship_type_friend_female' => 'vännina',
    'relationship_type_friend_male' => 'vän',
    'relationship_type_friend_with_name' => ':name\'s vännina',
    'relationship_type_friend_female_with_name' => ':name\'s vän',
    'relationship_type_friend_male_with_name' => ':name’s vän',

    'relationship_type_bestfriend' => 'bästa vän',
    'relationship_type_bestfriend_female' => 'bästa vän',
    'relationship_type_bestfriend_male' => 'bästa vän',
    'relationship_type_bestfriend_with_name' => ':name\'s bästa vän',
    'relationship_type_bestfriend_female_with_name' => ':name\'s bästa vän',
    'relationship_type_bestfriend_male_with_name' => ':name\'s bästa vän',

    'relationship_type_colleague' => 'kollega',
    'relationship_type_colleague_female' => 'kollega',
    'relationship_type_colleague_male' => 'kollega',
    'relationship_type_colleague_with_name' => ':name\'s kollega',
    'relationship_type_colleague_female_with_name' => ':name\'s kollega',
    'relationship_type_colleague_male_with_name' => ':name\'s kollega',

    'relationship_type_boss' => 'chef',
    'relationship_type_boss_female' => 'chef',
    'relationship_type_boss_male' => 'chef',
    'relationship_type_boss_with_name' => ':name\'s chef',
    'relationship_type_boss_female_with_name' => ':name\'s chef',
    'relationship_type_boss_male_with_name' => ':name\'s chef',

    'relationship_type_subordinate' => 'underordnad',
    'relationship_type_subordinate_female' => 'underordnad',
    'relationship_type_subordinate_male' => 'underordnad',
    'relationship_type_subordinate_with_name' => ':name\'s underordnade',
    'relationship_type_subordinate_female_with_name' => ':name\'s underordnade',
    'relationship_type_subordinate_male_with_name' => ':name\'s underordnade',

    'relationship_type_mentor' => 'mentor',
    'relationship_type_mentor_female' => 'mentor',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => ':name\'s mentor',
    'relationship_type_mentor_female_with_name' => ':name\'s mentor',
    'relationship_type_mentor_male_with_name' => ':name\'s mentor',

    'relationship_type_protege' => 'skyddsling',
    'relationship_type_protege_female' => 'skyddsling',
    'relationship_type_protege_male' => 'skyddsling',
    'relationship_type_protege_with_name' => ':name\'s skyddsling',
    'relationship_type_protege_female_with_name' => ':name\'s skyddsling',
    'relationship_type_protege_male_with_name' => ':name\'s skyddsling',

    'relationship_type_ex_husband' => 'ex-make',
    'relationship_type_ex_husband_female' => 'ex-fru',
    'relationship_type_ex_husband_male' => 'ex-make',
    'relationship_type_ex_husband_with_name' => ':name’s ex-make',
    'relationship_type_ex_husband_female_with_name' => ':name\'s ex-fru',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-make',

    // emotions
    'emotion_primary_love' => 'Kärlek',
    'emotion_primary_joy' => 'Glädje',
    'emotion_primary_surprise' => 'Överraskning',
    'emotion_primary_anger' => 'Ilska',
    'emotion_primary_sadness' => 'Sorg',
    'emotion_primary_fear' => 'Rädsla',

    'emotion_secondary_affection' => 'Tillgivenhet',
    'emotion_secondary_lust' => 'Lust',
    'emotion_secondary_longing' => 'Längtar',
    'emotion_secondary_cheerfulness' => 'Glädjande',
    'emotion_secondary_zest' => 'Iver',
    'emotion_secondary_contentment' => 'Belåtenhet',
    'emotion_secondary_pride' => 'Stolthet',
    'emotion_secondary_optimism' => 'Optimism',
    'emotion_secondary_enthrallment' => 'Fängslande',
    'emotion_secondary_relief' => 'Lättnad',
    'emotion_secondary_surprise' => 'Förvånad',
    'emotion_secondary_irritation' => 'Irriterad',
    'emotion_secondary_exasperation' => 'Irritation',
    'emotion_secondary_rage' => 'Raseri',
    'emotion_secondary_disgust' => 'Äcklad',
    'emotion_secondary_envy' => 'Avundsjuk',
    'emotion_secondary_suffering' => 'Lidande',
    'emotion_secondary_sadness' => 'Sorgsenhet',
    'emotion_secondary_disappointment' => 'Besvikelse',
    'emotion_secondary_shame' => 'Skam',
    'emotion_secondary_neglect' => 'Försumma',
    'emotion_secondary_sympathy' => 'Sympati',
    'emotion_secondary_horror' => 'Skräck',
    'emotion_secondary_nervousness' => 'Nervositet',

    'emotion_adoration' => 'Dyrkan',
    'emotion_affection' => 'Tillgivenhet',
    'emotion_love' => 'Kärlek',
    'emotion_fondness' => 'Förkärlek',
    'emotion_liking' => 'Gillar',
    'emotion_attraction' => 'Attraktiv',
    'emotion_caring' => 'Omtänksam',
    'emotion_tenderness' => 'Ömhet',
    'emotion_compassion' => 'Medlidande',
    'emotion_sentimentality' => 'Sentimentalitet',
    'emotion_arousal' => 'Upphetsning',
    'emotion_desire' => 'Åtrå',
    'emotion_lust' => 'Lust',
    'emotion_passion' => 'Passion',
    'emotion_infatuation' => 'Förblindelse',
    'emotion_longing' => 'Längtan',
    'emotion_amusement' => 'Nöjen',
    'emotion_bliss' => 'Överlyckling',
    'emotion_cheerfulness' => 'Glädjande',
    'emotion_gaiety' => 'Munterhet',
    'emotion_glee' => 'Munterhet',
    'emotion_jolliness' => 'Överlycklig',
    'emotion_joviality' => 'Gladlynt',
    'emotion_joy' => 'Glädje',
    'emotion_delight' => 'Fröjd',
    'emotion_enjoyment' => 'Njutning',
    'emotion_gladness' => 'Glad',
    'emotion_happiness' => 'Lycka',
    'emotion_jubilation' => 'Jubel',
    'emotion_elation' => 'Förtjusning',
    'emotion_satisfaction' => 'Tillfredsställelse',
    'emotion_ecstasy' => 'Extas',
    'emotion_euphoria' => 'Eufori',
    'emotion_enthusiasm' => 'Entusiastisk',
    'emotion_zeal' => 'Iver',
    'emotion_zest' => 'Iver',
    'emotion_excitement' => 'Upphetsning',
    'emotion_thrill' => 'Spänning',
    'emotion_exhilaration' => 'Upprymdhet',
    'emotion_contentment' => 'Belåtenhet',
    'emotion_pleasure' => 'Njutning',
    'emotion_pride' => 'Stolt',
    'emotion_eagerness' => 'Ivrighet',
    'emotion_hope' => 'Hopp',
    'emotion_optimism' => 'Optimism',
    'emotion_enthrallment' => 'Fängslande',
    'emotion_rapture' => 'Hänföra',
    'emotion_relief' => 'Lättnad',
    'emotion_amazement' => 'Häpnadsväckande',
    'emotion_surprise' => 'Överraskning',
    'emotion_astonishment' => 'Häpnad',
    'emotion_aggravation' => 'Försvårande',
    'emotion_irritation' => 'Irriterad',
    'emotion_agitation' => 'Agitation',
    'emotion_annoyance' => 'Irritation',
    'emotion_grouchiness' => 'Gnällig',
    'emotion_grumpiness' => 'Grinig',
    'emotion_exasperation' => 'Ursinne',
    'emotion_frustration' => 'Frustration',
    'emotion_anger' => 'Ilska',
    'emotion_rage' => 'Raseri',
    'emotion_outrage' => 'Skandalös',
    'emotion_fury' => 'Ursinne',
    'emotion_wrath' => 'Vrede',
    'emotion_hostility' => 'Fiendskap',
    'emotion_ferocity' => 'Blodtörstig',
    'emotion_bitterness' => 'Bitterhet',
    'emotion_hate' => 'Hat',
    'emotion_loathing' => 'Äcklad',
    'emotion_scorn' => 'Förakt',
    'emotion_spite' => 'Illvilja',
    'emotion_vengefulness' => 'Hämndlysten',
    'emotion_dislike' => 'Ogilla',
    'emotion_resentment' => 'Förbittring',
    'emotion_disgust' => 'Äcklad',
    'emotion_revulsion' => 'Bakslag',
    'emotion_contempt' => 'Förakt',
    'emotion_envy' => 'Avundsjuk',
    'emotion_jealousy' => 'Avundsjuka',
    'emotion_agony' => 'Ångest',
    'emotion_suffering' => 'Lidande',
    'emotion_hurt' => 'Sårad',
    'emotion_anguish' => 'Plåga',
    'emotion_depression' => 'Depression',
    'emotion_despair' => 'Förtvivla',
    'emotion_hopelessness' => 'Hopplöshet',
    'emotion_gloom' => 'Dyster',
    'emotion_glumness' => 'Dysterhet',
    'emotion_sadness' => 'Sorg',
    'emotion_unhappiness' => 'Olycka',
    'emotion_grief' => 'Sorg',
    'emotion_sorrow' => 'Sorg',
    'emotion_woe' => 'Olycka/Elände',
    'emotion_misery' => 'Elände',
    'emotion_melancholy' => 'Melankoli',
    'emotion_dismay' => 'Förfäran',
    'emotion_disappointment' => 'Besvikelse',
    'emotion_displeasure' => 'Missnöje',
    'emotion_guilt' => 'Skuld',
    'emotion_shame' => 'Skam',
    'emotion_regret' => 'Ånger',
    'emotion_remorse' => 'Ångersfull',
    'emotion_alienation' => 'Utanförskap',
    'emotion_isolation' => 'Isolering',
    'emotion_neglect' => 'Försumma',
    'emotion_loneliness' => 'Ensamhet',
    'emotion_rejection' => 'Avvisad',
    'emotion_homesickness' => 'Hemlängtan',
    'emotion_defeat' => 'Nederlag',
    'emotion_dejection' => 'Nedstämdhet',
    'emotion_insecurity' => 'Osäkerhet',
    'emotion_embarrassment' => 'Generad',
    'emotion_humiliation' => 'Förödmjukelse',
    'emotion_insult' => 'Förolämpning',
    'emotion_pity' => 'Medlidande',
    'emotion_sympathy' => 'Sympati',
    'emotion_alarm' => 'Alarm',
    'emotion_shock' => 'Chock',
    'emotion_fear' => 'Rädsla',
    'emotion_fright' => 'Skräck',
    'emotion_horror' => 'Skräck',
    'emotion_terror' => 'Terror',
    'emotion_panic' => 'Panik',
    'emotion_hysteria' => 'Hysteri',
    'emotion_mortification' => 'Förtret',
    'emotion_anxiety' => 'Ångest',
    'emotion_nervousness' => 'Nervositet',
    'emotion_tenseness' => 'Spänd',
    'emotion_uneasiness' => 'Obehaglighet',
    'emotion_apprehension' => 'Oro',
    'emotion_worry' => 'Oroande',
    'emotion_distress' => 'I nöd',
    'emotion_dread' => 'Fruktan',

    // weather
    'weather_sunny' => 'Soligt',
    'weather_clear' => 'Klart',
    'weather_clear-day' => 'Klar',
    'weather_clear-night' => 'Klart (natt)',
    'weather_light-drizzle' => 'Lätt duggregn',
    'weather_patchy-light-drizzle' => 'Fläckvis lätt duggregn',
    'weather_patchy-light-rain' => 'Fläckvis lätt regn',
    'weather_light-rain' => 'Lätt regn',
    'weather_moderate-rain-at-times' => 'Måttligt regn ibland',
    'weather_moderate-rain' => 'Måttligt regn',
    'weather_patchy-rain-possible' => 'Möjligen fläckvisa skurar',
    'weather_heavy-rain-at-times' => 'Möjligen mycket regn',
    'weather_heavy-rain' => 'Spöregn',
    'weather_light-freezing-rain' => 'Lätt underkylt regn',
    'weather_moderate-or-heavy-freezing-rain' => 'Måttlig eller kraftigt underkylt regn',
    'weather_light-sleet' => 'Lätt snöblandat',
    'weather_moderate-or-heavy-rain-shower' => 'Måttliga eller kraftiga regnskurar',
    'weather_light-rain-shower' => 'Lätta regnskurar',
    'weather_torrential-rain-shower' => 'Skyfall',
    'weather_rain' => 'Regn',
    'weather_snow' => 'Snö',
    'weather_blowing-snow' => 'Snövindar',
    'weather_patchy-light-snow' => 'Delvis lätt snöfall',
    'weather_light-snow' => 'Lätt snö',
    'weather_patchy-moderate-snow' => 'Fläckvis måttlig snö',
    'weather_moderate-snow' => 'Måttligt snöfall',
    'weather_patchy-heavy-snow' => 'Fläckvis kraftigt snöfall',
    'weather_heavy-snow' => 'Kraftigt snöfall',
    'weather_light-snow-showers' => 'Lätta snöbyar',
    'weather_moderate-or-heavy-snow-showers' => 'Måttliga eller kraftiga snöbyar',
    'weather_patchy-snow-possible' => 'Fläckvist snöfall möjligt',
    'weather_patchy-sleet-possible' => 'Fläckvis snöblandat regn möjligt',
    'weather_moderate-or-heavy-sleet' => 'Måttligt eller kraftigt snöblandat regn',
    'weather_light-sleet-showers' => 'Lätt snöblandat regn',
    'weather_moderate-or-heavy-sleet-showers' => 'Måttligt eller tungt snöblandat regn',
    'weather_sleet' => 'Nöje',
    'weather_wind' => 'Vind',
    'weather_fog' => 'Dimma',
    'weather_freezing-fog' => 'Underkyld dimma',
    'weather_mist' => 'Dimma',
    'weather_blizzard' => 'Snöstorm',
    'weather_overcast' => 'Mulet',
    'weather_cloudy' => 'Molnigt',
    'weather_partly-cloudy-day' => 'Växlande molnighet',
    'weather_partly-cloudy-night' => 'Växlande molnighet',
    'weather_freezing-drizzle' => 'Underkylt duggregn',
    'weather_heavy-freezing-drizzle' => 'Kraftigt underkylt duggregn',
    'weather_patchy-freezing-drizzle-possible' => 'Fäckvis underkylt duggren möjligt',
    'weather_ice-pellets' => 'Hagel',
    'weather_light-showers-of-ice-pellets' => 'Lätta skurar av hagel',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Måttliga eller tunga skurar av hagel',
    'weather_thundery-outbreaks-possible' => 'Möjlighet till åska',
    'weather_patchy-light-rain-with-thunder' => 'Fläckvis lätt regn med åska',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Måttliga eller tunga åskskurar',
    'weather_patchy-light-snow-with-thunder' => 'Fläckvis snö med åska',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Måttlig eller tung snö med åskbyar',
    'weather_current_temperature_celsius' => ':temperatur °C',
    'weather_current_temperature_fahrenheit' => ':temperatur °F',
    'weather_current_title' => 'Aktuell väderikon',

    // dav
    'dav_contacts' => 'Kontakter',
    'dav_contacts_description' => ':name\'s kontakter',
    'dav_birthdays' => 'Födelsedagar',
    'dav_birthdays_description' => ':name\'s kontakter födelsedagar',
    'dav_tasks' => 'Uppgifter',
    'dav_tasks_description' => ':name\'s uppgifter',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Kontakt',
    'contact_list_description' => 'Beskrivning',

];
